summaryrefslogtreecommitdiffstats
path: root/src/svnqt/cache/sqlite3/qsql_sqlite3.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-14 21:37:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-14 21:37:51 +0000
commit2176199f9c492656df911ca217ac32d03cb1931d (patch)
treee0f75a3f4f6a52b7a6e2777f622efed211ea2ef9 /src/svnqt/cache/sqlite3/qsql_sqlite3.cpp
parentc6b29717327388357badda064ef1ced71932406e (diff)
downloadtdesvn-2176199f9c492656df911ca217ac32d03cb1931d.tar.gz
tdesvn-2176199f9c492656df911ca217ac32d03cb1931d.zip
Convert accidental instances of STQL to the proper SQL
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kdesvn@1247182 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/svnqt/cache/sqlite3/qsql_sqlite3.cpp')
-rw-r--r--src/svnqt/cache/sqlite3/qsql_sqlite3.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/svnqt/cache/sqlite3/qsql_sqlite3.cpp b/src/svnqt/cache/sqlite3/qsql_sqlite3.cpp
index 408cb32..1f4e616 100644
--- a/src/svnqt/cache/sqlite3/qsql_sqlite3.cpp
+++ b/src/svnqt/cache/sqlite3/qsql_sqlite3.cpp
@@ -1,6 +1,6 @@
/****************************************************************************
**
** Implementation of STQLite driver classes.
**
** Copyright (C) 1992-2003 Trolltech AS. All rights reserved.
**
@@ -285,7 +285,7 @@ bool TQSQLite3Driver::hasFeature(DriverFeature f) const
}
/*
- STQLite dbs have no user name, passwords, hosts or ports.
+ SQLite dbs have no user name, passwords, hosts or ports.
just file names.
*/
bool TQSQLite3Driver::open(const TQString & db, const TQString &, const TQString &, const TQString &, int, const TQString &)
@@ -1,6 +1,6 @@
/****************************************************************************
**
-** Implementation of STQLite driver classes.
+** Implementation of SQLite driver classes.
**
** Copyright (C) 1992-2003 Trolltech AS. All rights reserved.